SCRIPT_TO_LANG = {
    'LATIN': 'en',
    'CYRILLIC': 'ru',
    'GREEK': 'el',
    'ARABIC': 'ar',
    'HEBREW': 'he',
    'DEVANAGARI': 'hi',
    'BENGALI': 'bn',
    'GUJARATI': 'gu',
    'GURMUKHI': 'pa',
    'TAMIL': 'ta',
    'TELUGU': 'te',
    'KANNADA': 'kn',
    'MALAYALAM': 'ml',
    'SINHALA': 'si',
    'THAI': 'th',
    'LAO': 'lo',
    'TIBETAN': 'bo',
    'MYANMAR': 'my',
    'GEORGIAN': 'ka',
    'HANGUL': 'ko',
    'HIRAGANA': 'ja',
    'KATAKANA': 'ja',
    'HAN': 'zh',
    'ARMENIAN': 'hy',
    'ETHIOPIC': 'am',
    'KHMER': 'km',
    'MONGOLIAN': 'mn',
    'CANADIAN': 'iu',
    'YI': 'ii',
    'CHEROKEE': 'chr',
    'THAANA': 'dv',
    'SYRIAC': 'syr',
    'SAMARITAN': 'sam',
    'MANDAIC': 'myz',
    'NKO': 'nqo',
    'TIFINAGH': 'ber',
    'OGHAM': 'sga',
    'RUNIC': 'non',
    'TAGALOG': 'tl',
    'HANUNOO': 'hnn',
    'BUHID': 'bku',
    'TAGBANWA': 'tbw',
    'LIMBU': 'lif',
    'TAI': 'tai',
    'BUGINESE': 'bug',
    'BALINESE': 'ban',
    'SUNDANESE': 'su',
    'LEPCHA': 'lep',
    'OL': 'sat',
    'JAVANESE': 'jv',
    'CHAM': 'cjm',
    'KAYAH': 'kyu',
    'REJANG': 'rej',
    'LYCIAN': 'xlc',
    'CARIAN': 'xcr',
    'LYDIAN': 'xld',
    'PHAGS-PA': 'xng',
    'PHOENICIAN': 'phn',
    'AVESTAN': 'ae',
    'IMPERIAL': 'xpr',
    'PARTHIAN': 'xpr',
    'PAHLAVI': 'pal',
    'PSALTER': 'pal',
    'OLD': 'xpr',
    'INSCRIPTIONAL': 'xpr',
    'BRAHMI': 'pra',
    'KAITHI': 'bh',
    'SORA': 'srb',
    'CHAKMA': 'ccp',
    'SHARADA': 'sa',
    'TAKRI': 'doi',
    'CUNEIFORM': 'akk',
    'EGYPTIAN': 'egy',
    'MEROITIC': 'xmr',
    'KHAROSHTHI': 'kho',
    'OSMANYA': 'so',
    'ELBASAN': 'sq',
    'CAUCASIAN': 'aqc',
    'LINEAR': 'grc',
    'CYPRIOT': 'grc',
    'PALMYRENE': 'arc',
    'NABATAEAN': 'arc',
    'HATRAN': 'arc',
    'PHOENICIAN': 'phn',
    'COPTIC': 'cop',
    'GOTHIC': 'got',
    'GLAGOLITIC': 'cu',
    'DESERET': 'en',
    'SHAVIAN': 'en',
    'OSMANYA': 'so',
    'TIFINAGH': 'ber',
    'BAMUM': 'bax',
    'VAI': 'vai',
    'MENDE': 'men',
}


from collections import Counter
import unicodedata
from .constants import SCRIPT_TO_LANG


def detect_language_distribution(text: str) -> dict:
    if not text:
        return {}
    
    char_counts = Counter()
    
    for char in text:
        if not char.isalnum():
            continue
            
        try:
            script = unicodedata.name(char).split()[0]
            if script in SCRIPT_TO_LANG:
                lang = SCRIPT_TO_LANG[script]
                char_counts[lang] += 1
        except (ValueError, IndexError):
            continue
    
    total = sum(char_counts.values())
    if total == 0:
        return {}

    return {
        lang: {
            "chars": count,
            "percent": round(count / total, 3)
        }
        for lang, count in char_counts.items()
    }


import unicodedata
from .detection import detect_language_distribution
from .processing import clean_text


def analyze(text: str) -> dict:
    if not text:
        return {}

    normalized = unicodedata.normalize("NFC", text)
    cleaned = clean_text(normalized)
    
    return detect_language_distribution(cleaned)


import unicodedata
import re


def clean_text(text: str) -> str:
    cleaned = ''.join(
        char for char in text
        if unicodedata.category(char)[0] in ('L', 'M') or char.isspace()
    )
    return re.sub(r"\s+", " ", cleaned).strip()